@@ -7,9 +7,9 @@ use Params::Validate qw(validate_pos SCALAR ARRAYREF);
 use Readonly;
 use base qw(Exporter);
 use English qw( -no_match_vars );
-use 5.005.03; 
+use 5.006;
 
-$VERSION   = '0.08';
+$VERSION   = '0.09';
 @EXPORT_OK = qw(validate validateFI generate);
 
 use constant MODULUS_OPERAND => 10;
@@ -18,7 +18,7 @@ use constant DEDUCTION       => 9;
 use constant INVALID         => 0;
 use constant VALID           => 1;
 
-Readonly::Array my @CONTROLCIFERS  => qw(1 2 1 2 1 2 1 2 1 2 1 2 1 2);
+Readonly::Array my @CONTROLCIFERS   => qw(1 2 1 2 1 2 1 2 1 2 1 2 1 2);
 Readonly::Scalar my $CONTROL_LENGTH => scalar @CONTROLCIFERS;
 
 ## no critic (NamingConventions::Capitalization)
@@ -41,7 +41,8 @@ sub validate {
 
     if ( $checksum == $last_digit ) {
         return VALID;
-    } else {
+    }
+    else {
         return INVALID;
     }
 }
@@ -72,7 +73,8 @@ sub _calculate_sum {
 
         if ( $tmp_sum >= THRESHOLD ) {
             $sum += ( $tmp_sum - DEDUCTION );
-        } else {
+        }
+        else {
             $sum += $tmp_sum;
         }
     }
@@ -114,13 +116,21 @@ __END__
 
 =pod
 
+=begin markdown
+
+[![CPAN version](https://badge.fury.io/pl/Business-DK-FI.svg)](http://badge.fury.io/pl/Business-DK-FI)
+[![Build Status](https://travis-ci.org/jonasbn/bdkfi.svg?branch=master)](https://travis-ci.org/jonasbn/bdkfi)
+[![Coverage Status](https://coveralls.io/repos/jonasbn/bdkfi/badge.png)](https://coveralls.io/r/jonasbn/bdkfi)
+
+=end markdown
+
 =head1 NAME
 
 Business::DK::FI - Danish FI number validator
 
 =head1 VERSION
 
-The documentation describes version 0.08
+The documentation describes version 0.09
 
 =head1 SYNOPSIS
 
@@ -304,7 +314,7 @@ Jonas B. Nielsen, (jonasbn) - C<< <jonasbn@cpan.org> >>
 
 =head1 COPYRIGHT
 
-Business-DK-FI and related is (C) by Jonas B. Nielsen, (jonasbn) 2009-2014
+Business-DK-FI and related is (C) by Jonas B. Nielsen, (jonasbn) 2009-2016
 
 =head1 LICENSE
 
